Documentation
¶
Index ¶
- Variables
- func RegisterPushServiceServer(s *grpc.Server, srv PushServiceServer)
- type ActivateSubscriptionRequest
- func (*ActivateSubscriptionRequest) Descriptor() ([]byte, []int)
- func (m *ActivateSubscriptionRequest) GetSubscription() *Subscription
- func (*ActivateSubscriptionRequest) ProtoMessage()
- func (m *ActivateSubscriptionRequest) Reset()
- func (m *ActivateSubscriptionRequest) String() string
- func (m *ActivateSubscriptionRequest) XXX_DiscardUnknown()
- func (m *ActivateSubscriptionRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ActivateSubscriptionRequest) XXX_Merge(src proto.Message)
- func (m *ActivateSubscriptionRequest) XXX_Size() int
- func (m *ActivateSubscriptionRequest) XXX_Unmarshal(b []byte) error
- type ActivateSubscriptionResponse
- func (*ActivateSubscriptionResponse) Descriptor() ([]byte, []int)
- func (m *ActivateSubscriptionResponse) GetMessage() string
- func (*ActivateSubscriptionResponse) ProtoMessage()
- func (m *ActivateSubscriptionResponse) Reset()
- func (m *ActivateSubscriptionResponse) String() string
- func (m *ActivateSubscriptionResponse) XXX_DiscardUnknown()
- func (m *ActivateSubscriptionResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *ActivateSubscriptionResponse) XXX_Merge(src proto.Message)
- func (m *ActivateSubscriptionResponse) XXX_Size() int
- func (m *ActivateSubscriptionResponse) XXX_Unmarshal(b []byte) error
- type DeactivateSubscriptionRequest
- func (*DeactivateSubscriptionRequest) Descriptor() ([]byte, []int)
- func (m *DeactivateSubscriptionRequest) GetFullName() string
- func (*DeactivateSubscriptionRequest) ProtoMessage()
- func (m *DeactivateSubscriptionRequest) Reset()
- func (m *DeactivateSubscriptionRequest) String() string
- func (m *DeactivateSubscriptionRequest) XXX_DiscardUnknown()
- func (m *DeactivateSubscriptionRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *DeactivateSubscriptionRequest) XXX_Merge(src proto.Message)
- func (m *DeactivateSubscriptionRequest) XXX_Size() int
- func (m *DeactivateSubscriptionRequest) XXX_Unmarshal(b []byte) error
- type DeactivateSubscriptionResponse
- func (*DeactivateSubscriptionResponse) Descriptor() ([]byte, []int)
- func (m *DeactivateSubscriptionResponse) GetMessage() string
- func (*DeactivateSubscriptionResponse) ProtoMessage()
- func (m *DeactivateSubscriptionResponse) Reset()
- func (m *DeactivateSubscriptionResponse) String() string
- func (m *DeactivateSubscriptionResponse) XXX_DiscardUnknown()
- func (m *DeactivateSubscriptionResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *DeactivateSubscriptionResponse) XXX_Merge(src proto.Message)
- func (m *DeactivateSubscriptionResponse) XXX_Size() int
- func (m *DeactivateSubscriptionResponse) XXX_Unmarshal(b []byte) error
- type PushConfig
- func (*PushConfig) Descriptor() ([]byte, []int)
- func (m *PushConfig) GetAuthorizationHeader() string
- func (m *PushConfig) GetBase_64Decode() bool
- func (m *PushConfig) GetMattermostChannel() string
- func (m *PushConfig) GetMattermostUrl() string
- func (m *PushConfig) GetMattermostUsername() string
- func (m *PushConfig) GetMaxMessages() int64
- func (m *PushConfig) GetPushEndpoint() string
- func (m *PushConfig) GetRetryPolicy() *RetryPolicy
- func (m *PushConfig) GetType() PushType
- func (*PushConfig) ProtoMessage()
- func (m *PushConfig) Reset()
- func (m *PushConfig) String() string
- func (m *PushConfig) XXX_DiscardUnknown()
- func (m *PushConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *PushConfig) XXX_Merge(src proto.Message)
- func (m *PushConfig) XXX_Size() int
- func (m *PushConfig) XXX_Unmarshal(b []byte) error
- type PushServiceClient
- type PushServiceServer
- type PushType
- type RetryPolicy
- func (*RetryPolicy) Descriptor() ([]byte, []int)
- func (m *RetryPolicy) GetPeriod() uint32
- func (m *RetryPolicy) GetType() string
- func (*RetryPolicy) ProtoMessage()
- func (m *RetryPolicy) Reset()
- func (m *RetryPolicy) String() string
- func (m *RetryPolicy) XXX_DiscardUnknown()
- func (m *RetryPolicy) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *RetryPolicy) XXX_Merge(src proto.Message)
- func (m *RetryPolicy) XXX_Size() int
- func (m *RetryPolicy) XXX_Unmarshal(b []byte) error
- type StatusRequest
- func (*StatusRequest) Descriptor() ([]byte, []int)
- func (*StatusRequest) ProtoMessage()
- func (m *StatusRequest) Reset()
- func (m *StatusRequest) String() string
- func (m *StatusRequest) XXX_DiscardUnknown()
- func (m *StatusRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *StatusRequest) XXX_Merge(src proto.Message)
- func (m *StatusRequest) XXX_Size() int
- func (m *StatusRequest) XXX_Unmarshal(b []byte) error
- type StatusResponse
- func (*StatusResponse) Descriptor() ([]byte, []int)
- func (*StatusResponse) ProtoMessage()
- func (m *StatusResponse) Reset()
- func (m *StatusResponse) String() string
- func (m *StatusResponse) XXX_DiscardUnknown()
- func (m *StatusResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *StatusResponse) XXX_Merge(src proto.Message)
- func (m *StatusResponse) XXX_Size() int
- func (m *StatusResponse) XXX_Unmarshal(b []byte) error
- type Subscription
- func (*Subscription) Descriptor() ([]byte, []int)
- func (m *Subscription) GetFullName() string
- func (m *Subscription) GetFullTopic() string
- func (m *Subscription) GetPushConfig() *PushConfig
- func (*Subscription) ProtoMessage()
- func (m *Subscription) Reset()
- func (m *Subscription) String() string
- func (m *Subscription) XXX_DiscardUnknown()
- func (m *Subscription) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *Subscription) XXX_Merge(src proto.Message)
- func (m *Subscription) XXX_Size() int
- func (m *Subscription) XXX_Unmarshal(b []byte) error
- type SubscriptionStatusRequest
- func (*SubscriptionStatusRequest) Descriptor() ([]byte, []int)
- func (m *SubscriptionStatusRequest) GetFullName() string
- func (*SubscriptionStatusRequest) ProtoMessage()
- func (m *SubscriptionStatusRequest) Reset()
- func (m *SubscriptionStatusRequest) String() string
- func (m *SubscriptionStatusRequest) XXX_DiscardUnknown()
- func (m *SubscriptionStatusRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *SubscriptionStatusRequest) XXX_Merge(src proto.Message)
- func (m *SubscriptionStatusRequest) XXX_Size() int
- func (m *SubscriptionStatusRequest) XXX_Unmarshal(b []byte) error
- type SubscriptionStatusResponse
- func (*SubscriptionStatusResponse) Descriptor() ([]byte, []int)
- func (m *SubscriptionStatusResponse) GetStatus() string
- func (*SubscriptionStatusResponse) ProtoMessage()
- func (m *SubscriptionStatusResponse) Reset()
- func (m *SubscriptionStatusResponse) String() string
- func (m *SubscriptionStatusResponse) XXX_DiscardUnknown()
- func (m *SubscriptionStatusResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (m *SubscriptionStatusResponse) XXX_Merge(src proto.Message)
- func (m *SubscriptionStatusResponse) XXX_Size() int
- func (m *SubscriptionStatusResponse) XXX_Unmarshal(b []byte) error
Constants ¶
This section is empty.
Variables ¶
var PushType_name = map[int32]string{
0: "HTTP_ENDPOINT",
1: "MATTERMOST",
}
var PushType_value = map[string]int32{
"HTTP_ENDPOINT": 0,
"MATTERMOST": 1,
}
Functions ¶
func RegisterPushServiceServer ¶
func RegisterPushServiceServer(s *grpc.Server, srv PushServiceServer)
Types ¶
type ActivateSubscriptionRequest ¶
type ActivateSubscriptionRequest struct {
// Required. A subscription.
Subscription *Subscription `protobuf:"bytes,1,opt,name=subscription,proto3" json:"subscription,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Wrapper for subscription.
func (*ActivateSubscriptionRequest) Descriptor ¶
func (*ActivateSubscriptionRequest) Descriptor() ([]byte, []int)
func (*ActivateSubscriptionRequest) GetSubscription ¶
func (m *ActivateSubscriptionRequest) GetSubscription() *Subscription
func (*ActivateSubscriptionRequest) ProtoMessage ¶
func (*ActivateSubscriptionRequest) ProtoMessage()
func (*ActivateSubscriptionRequest) Reset ¶
func (m *ActivateSubscriptionRequest) Reset()
func (*ActivateSubscriptionRequest) String ¶
func (m *ActivateSubscriptionRequest) String() string
func (*ActivateSubscriptionRequest) XXX_DiscardUnknown ¶
func (m *ActivateSubscriptionRequest) XXX_DiscardUnknown()
func (*ActivateSubscriptionRequest) XXX_Marshal ¶
func (m *ActivateSubscriptionRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ActivateSubscriptionRequest) XXX_Merge ¶
func (m *ActivateSubscriptionRequest) XXX_Merge(src proto.Message)
func (*ActivateSubscriptionRequest) XXX_Size ¶
func (m *ActivateSubscriptionRequest) XXX_Size() int
func (*ActivateSubscriptionRequest) XXX_Unmarshal ¶
func (m *ActivateSubscriptionRequest) XXX_Unmarshal(b []byte) error
type ActivateSubscriptionResponse ¶
type ActivateSubscriptionResponse struct {
// Message response
Message string `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Wrapper for subscription
func (*ActivateSubscriptionResponse) Descriptor ¶
func (*ActivateSubscriptionResponse) Descriptor() ([]byte, []int)
func (*ActivateSubscriptionResponse) GetMessage ¶
func (m *ActivateSubscriptionResponse) GetMessage() string
func (*ActivateSubscriptionResponse) ProtoMessage ¶
func (*ActivateSubscriptionResponse) ProtoMessage()
func (*ActivateSubscriptionResponse) Reset ¶
func (m *ActivateSubscriptionResponse) Reset()
func (*ActivateSubscriptionResponse) String ¶
func (m *ActivateSubscriptionResponse) String() string
func (*ActivateSubscriptionResponse) XXX_DiscardUnknown ¶
func (m *ActivateSubscriptionResponse) XXX_DiscardUnknown()
func (*ActivateSubscriptionResponse) XXX_Marshal ¶
func (m *ActivateSubscriptionResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ActivateSubscriptionResponse) XXX_Merge ¶
func (m *ActivateSubscriptionResponse) XXX_Merge(src proto.Message)
func (*ActivateSubscriptionResponse) XXX_Size ¶
func (m *ActivateSubscriptionResponse) XXX_Size() int
func (*ActivateSubscriptionResponse) XXX_Unmarshal ¶
func (m *ActivateSubscriptionResponse) XXX_Unmarshal(b []byte) error
type DeactivateSubscriptionRequest ¶
type DeactivateSubscriptionRequest struct {
// Required. The full resource name of the subscrption.
FullName string `protobuf:"bytes,1,opt,name=full_name,json=fullName,proto3" json:"full_name,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Contains which subscription to deactivate
func (*DeactivateSubscriptionRequest) Descriptor ¶
func (*DeactivateSubscriptionRequest) Descriptor() ([]byte, []int)
func (*DeactivateSubscriptionRequest) GetFullName ¶
func (m *DeactivateSubscriptionRequest) GetFullName() string
func (*DeactivateSubscriptionRequest) ProtoMessage ¶
func (*DeactivateSubscriptionRequest) ProtoMessage()
func (*DeactivateSubscriptionRequest) Reset ¶
func (m *DeactivateSubscriptionRequest) Reset()
func (*DeactivateSubscriptionRequest) String ¶
func (m *DeactivateSubscriptionRequest) String() string
func (*DeactivateSubscriptionRequest) XXX_DiscardUnknown ¶
func (m *DeactivateSubscriptionRequest) XXX_DiscardUnknown()
func (*DeactivateSubscriptionRequest) XXX_Marshal ¶
func (m *DeactivateSubscriptionRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*DeactivateSubscriptionRequest) XXX_Merge ¶
func (m *DeactivateSubscriptionRequest) XXX_Merge(src proto.Message)
func (*DeactivateSubscriptionRequest) XXX_Size ¶
func (m *DeactivateSubscriptionRequest) XXX_Size() int
func (*DeactivateSubscriptionRequest) XXX_Unmarshal ¶
func (m *DeactivateSubscriptionRequest) XXX_Unmarshal(b []byte) error
type DeactivateSubscriptionResponse ¶
type DeactivateSubscriptionResponse struct {
// Message response
Message string `protobuf:"bytes,1,opt,name=message,proto3" json:"message,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Wrapper for subscription
func (*DeactivateSubscriptionResponse) Descriptor ¶
func (*DeactivateSubscriptionResponse) Descriptor() ([]byte, []int)
func (*DeactivateSubscriptionResponse) GetMessage ¶
func (m *DeactivateSubscriptionResponse) GetMessage() string
func (*DeactivateSubscriptionResponse) ProtoMessage ¶
func (*DeactivateSubscriptionResponse) ProtoMessage()
func (*DeactivateSubscriptionResponse) Reset ¶
func (m *DeactivateSubscriptionResponse) Reset()
func (*DeactivateSubscriptionResponse) String ¶
func (m *DeactivateSubscriptionResponse) String() string
func (*DeactivateSubscriptionResponse) XXX_DiscardUnknown ¶
func (m *DeactivateSubscriptionResponse) XXX_DiscardUnknown()
func (*DeactivateSubscriptionResponse) XXX_Marshal ¶
func (m *DeactivateSubscriptionResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*DeactivateSubscriptionResponse) XXX_Merge ¶
func (m *DeactivateSubscriptionResponse) XXX_Merge(src proto.Message)
func (*DeactivateSubscriptionResponse) XXX_Size ¶
func (m *DeactivateSubscriptionResponse) XXX_Size() int
func (*DeactivateSubscriptionResponse) XXX_Unmarshal ¶
func (m *DeactivateSubscriptionResponse) XXX_Unmarshal(b []byte) error
type PushConfig ¶
type PushConfig struct {
// Required. An https endpoint to where the messages will be pushed.
PushEndpoint string `protobuf:"bytes,1,opt,name=push_endpoint,json=pushEndpoint,proto3" json:"push_endpoint,omitempty"`
// Defaults to 1. How many messages should the push server consume and sent at once.
MaxMessages int64 `protobuf:"varint,3,opt,name=max_messages,json=maxMessages,proto3" json:"max_messages,omitempty"`
// Required. Retry policy.
RetryPolicy *RetryPolicy `protobuf:"bytes,2,opt,name=retry_policy,json=retryPolicy,proto3" json:"retry_policy,omitempty"`
// Required. Authorization header that the sent messages should include into the request
AuthorizationHeader string `protobuf:"bytes,4,opt,name=authorization_header,json=authorizationHeader,proto3" json:"authorization_header,omitempty"`
// Required. Defines the type of the destination the data will be sent to.
// Can be either http_endpoint or mattermost
Type PushType `protobuf:"varint,5,opt,name=type,proto3,enum=PushType" json:"type,omitempty"`
// Mattermost webhook url
MattermostUrl string `protobuf:"bytes,6,opt,name=mattermost_url,json=mattermostUrl,proto3" json:"mattermost_url,omitempty"`
// Mattermost username that the messages will be displayed under
MattermostUsername string `protobuf:"bytes,7,opt,name=mattermost_username,json=mattermostUsername,proto3" json:"mattermost_username,omitempty"`
// Mattermost channel that the messages will be delivered to
MattermostChannel string `protobuf:"bytes,8,opt,name=mattermost_channel,json=mattermostChannel,proto3" json:"mattermost_channel,omitempty"`
// Indicates whether or not the payload should be decoded before being pushed to any remote destination
Base_64Decode bool `protobuf:"varint,9,opt,name=base_64_decode,json=base64Decode,proto3" json:"base_64_decode,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
PushConfig holds information on how a push subscription functions.
func (*PushConfig) Descriptor ¶
func (*PushConfig) Descriptor() ([]byte, []int)
func (*PushConfig) GetAuthorizationHeader ¶
func (m *PushConfig) GetAuthorizationHeader() string
func (*PushConfig) GetBase_64Decode ¶
func (m *PushConfig) GetBase_64Decode() bool
func (*PushConfig) GetMattermostChannel ¶
func (m *PushConfig) GetMattermostChannel() string
func (*PushConfig) GetMattermostUrl ¶
func (m *PushConfig) GetMattermostUrl() string
func (*PushConfig) GetMattermostUsername ¶
func (m *PushConfig) GetMattermostUsername() string
func (*PushConfig) GetMaxMessages ¶
func (m *PushConfig) GetMaxMessages() int64
func (*PushConfig) GetPushEndpoint ¶
func (m *PushConfig) GetPushEndpoint() string
func (*PushConfig) GetRetryPolicy ¶
func (m *PushConfig) GetRetryPolicy() *RetryPolicy
func (*PushConfig) GetType ¶
func (m *PushConfig) GetType() PushType
func (*PushConfig) ProtoMessage ¶
func (*PushConfig) ProtoMessage()
func (*PushConfig) Reset ¶
func (m *PushConfig) Reset()
func (*PushConfig) String ¶
func (m *PushConfig) String() string
func (*PushConfig) XXX_DiscardUnknown ¶
func (m *PushConfig) XXX_DiscardUnknown()
func (*PushConfig) XXX_Marshal ¶
func (m *PushConfig) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*PushConfig) XXX_Merge ¶
func (m *PushConfig) XXX_Merge(src proto.Message)
func (*PushConfig) XXX_Size ¶
func (m *PushConfig) XXX_Size() int
func (*PushConfig) XXX_Unmarshal ¶
func (m *PushConfig) XXX_Unmarshal(b []byte) error
type PushServiceClient ¶
type PushServiceClient interface {
// Activates a subscription in order for the service to start handling the push functionality
ActivateSubscription(ctx context.Context, in *ActivateSubscriptionRequest, opts ...grpc.CallOption) (*ActivateSubscriptionResponse, error)
// Deactivates a subscription in order for the service to stop handling the push functionality
DeactivateSubscription(ctx context.Context, in *DeactivateSubscriptionRequest, opts ...grpc.CallOption) (*DeactivateSubscriptionResponse, error)
// Status returns the current state of the service
Status(ctx context.Context, in *StatusRequest, opts ...grpc.CallOption) (*StatusResponse, error)
// SubscriptionStatus returns the status of the worker that handles the respective subscription
SubscriptionStatus(ctx context.Context, in *SubscriptionStatusRequest, opts ...grpc.CallOption) (*SubscriptionStatusResponse, error)
}
PushServiceClient is the client API for PushService service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewPushServiceClient ¶
func NewPushServiceClient(cc *grpc.ClientConn) PushServiceClient
type PushServiceServer ¶
type PushServiceServer interface {
// Activates a subscription in order for the service to start handling the push functionality
ActivateSubscription(context.Context, *ActivateSubscriptionRequest) (*ActivateSubscriptionResponse, error)
// Deactivates a subscription in order for the service to stop handling the push functionality
DeactivateSubscription(context.Context, *DeactivateSubscriptionRequest) (*DeactivateSubscriptionResponse, error)
// Status returns the current state of the service
Status(context.Context, *StatusRequest) (*StatusResponse, error)
// SubscriptionStatus returns the status of the worker that handles the respective subscription
SubscriptionStatus(context.Context, *SubscriptionStatusRequest) (*SubscriptionStatusResponse, error)
}
PushServiceServer is the server API for PushService service.
type PushType ¶
type PushType int32
PushType declares what kind of push configuration info a subscription will hold
func (PushType) EnumDescriptor ¶
type RetryPolicy ¶
type RetryPolicy struct {
// Required. Type of the retry policy used (Only linear policy supported).
Type string `protobuf:"bytes,1,opt,name=type,proto3" json:"type,omitempty"`
// Required. Retry period in milliseconds.
Period uint32 `protobuf:"varint,2,opt,name=period,proto3" json:"period,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
RetryPolicy holds information regarding the retry policy.
func (*RetryPolicy) Descriptor ¶
func (*RetryPolicy) Descriptor() ([]byte, []int)
func (*RetryPolicy) GetPeriod ¶
func (m *RetryPolicy) GetPeriod() uint32
func (*RetryPolicy) GetType ¶
func (m *RetryPolicy) GetType() string
func (*RetryPolicy) ProtoMessage ¶
func (*RetryPolicy) ProtoMessage()
func (*RetryPolicy) Reset ¶
func (m *RetryPolicy) Reset()
func (*RetryPolicy) String ¶
func (m *RetryPolicy) String() string
func (*RetryPolicy) XXX_DiscardUnknown ¶
func (m *RetryPolicy) XXX_DiscardUnknown()
func (*RetryPolicy) XXX_Marshal ¶
func (m *RetryPolicy) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*RetryPolicy) XXX_Merge ¶
func (m *RetryPolicy) XXX_Merge(src proto.Message)
func (*RetryPolicy) XXX_Size ¶
func (m *RetryPolicy) XXX_Size() int
func (*RetryPolicy) XXX_Unmarshal ¶
func (m *RetryPolicy) XXX_Unmarshal(b []byte) error
type StatusRequest ¶
type StatusRequest struct {
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Empty wrapper for status request call
func (*StatusRequest) Descriptor ¶
func (*StatusRequest) Descriptor() ([]byte, []int)
func (*StatusRequest) ProtoMessage ¶
func (*StatusRequest) ProtoMessage()
func (*StatusRequest) Reset ¶
func (m *StatusRequest) Reset()
func (*StatusRequest) String ¶
func (m *StatusRequest) String() string
func (*StatusRequest) XXX_DiscardUnknown ¶
func (m *StatusRequest) XXX_DiscardUnknown()
func (*StatusRequest) XXX_Marshal ¶
func (m *StatusRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*StatusRequest) XXX_Merge ¶
func (m *StatusRequest) XXX_Merge(src proto.Message)
func (*StatusRequest) XXX_Size ¶
func (m *StatusRequest) XXX_Size() int
func (*StatusRequest) XXX_Unmarshal ¶
func (m *StatusRequest) XXX_Unmarshal(b []byte) error
type StatusResponse ¶
type StatusResponse struct {
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Empty wrapper for status response call
func (*StatusResponse) Descriptor ¶
func (*StatusResponse) Descriptor() ([]byte, []int)
func (*StatusResponse) ProtoMessage ¶
func (*StatusResponse) ProtoMessage()
func (*StatusResponse) Reset ¶
func (m *StatusResponse) Reset()
func (*StatusResponse) String ¶
func (m *StatusResponse) String() string
func (*StatusResponse) XXX_DiscardUnknown ¶
func (m *StatusResponse) XXX_DiscardUnknown()
func (*StatusResponse) XXX_Marshal ¶
func (m *StatusResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*StatusResponse) XXX_Merge ¶
func (m *StatusResponse) XXX_Merge(src proto.Message)
func (*StatusResponse) XXX_Size ¶
func (m *StatusResponse) XXX_Size() int
func (*StatusResponse) XXX_Unmarshal ¶
func (m *StatusResponse) XXX_Unmarshal(b []byte) error
type Subscription ¶
type Subscription struct {
// Required. The full resource name of the subscription.
FullName string `protobuf:"bytes,1,opt,name=full_name,json=fullName,proto3" json:"full_name,omitempty"`
// The full topic name of the topic that the subscription is associated.
FullTopic string `protobuf:"bytes,2,opt,name=full_topic,json=fullTopic,proto3" json:"full_topic,omitempty"`
// Required. Information regarding the push functionality.
PushConfig *PushConfig `protobuf:"bytes,4,opt,name=push_config,json=pushConfig,proto3" json:"push_config,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Subscription holds informaton related to how the push functionality should operate.
func (*Subscription) Descriptor ¶
func (*Subscription) Descriptor() ([]byte, []int)
func (*Subscription) GetFullName ¶
func (m *Subscription) GetFullName() string
func (*Subscription) GetFullTopic ¶
func (m *Subscription) GetFullTopic() string
func (*Subscription) GetPushConfig ¶
func (m *Subscription) GetPushConfig() *PushConfig
func (*Subscription) ProtoMessage ¶
func (*Subscription) ProtoMessage()
func (*Subscription) Reset ¶
func (m *Subscription) Reset()
func (*Subscription) String ¶
func (m *Subscription) String() string
func (*Subscription) XXX_DiscardUnknown ¶
func (m *Subscription) XXX_DiscardUnknown()
func (*Subscription) XXX_Marshal ¶
func (m *Subscription) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*Subscription) XXX_Merge ¶
func (m *Subscription) XXX_Merge(src proto.Message)
func (*Subscription) XXX_Size ¶
func (m *Subscription) XXX_Size() int
func (*Subscription) XXX_Unmarshal ¶
func (m *Subscription) XXX_Unmarshal(b []byte) error
type SubscriptionStatusRequest ¶
type SubscriptionStatusRequest struct {
// Required. The full resource name of the subscrption.
FullName string `protobuf:"bytes,1,opt,name=full_name,json=fullName,proto3" json:"full_name,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Empty wrapper for status request call
func (*SubscriptionStatusRequest) Descriptor ¶
func (*SubscriptionStatusRequest) Descriptor() ([]byte, []int)
func (*SubscriptionStatusRequest) GetFullName ¶
func (m *SubscriptionStatusRequest) GetFullName() string
func (*SubscriptionStatusRequest) ProtoMessage ¶
func (*SubscriptionStatusRequest) ProtoMessage()
func (*SubscriptionStatusRequest) Reset ¶
func (m *SubscriptionStatusRequest) Reset()
func (*SubscriptionStatusRequest) String ¶
func (m *SubscriptionStatusRequest) String() string
func (*SubscriptionStatusRequest) XXX_DiscardUnknown ¶
func (m *SubscriptionStatusRequest) XXX_DiscardUnknown()
func (*SubscriptionStatusRequest) XXX_Marshal ¶
func (m *SubscriptionStatusRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*SubscriptionStatusRequest) XXX_Merge ¶
func (m *SubscriptionStatusRequest) XXX_Merge(src proto.Message)
func (*SubscriptionStatusRequest) XXX_Size ¶
func (m *SubscriptionStatusRequest) XXX_Size() int
func (*SubscriptionStatusRequest) XXX_Unmarshal ¶
func (m *SubscriptionStatusRequest) XXX_Unmarshal(b []byte) error
type SubscriptionStatusResponse ¶
type SubscriptionStatusResponse struct {
// Required. The full resource name of the subscrption.
Status string `protobuf:"bytes,1,opt,name=status,proto3" json:"status,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
Empty wrapper for status response call
func (*SubscriptionStatusResponse) Descriptor ¶
func (*SubscriptionStatusResponse) Descriptor() ([]byte, []int)
func (*SubscriptionStatusResponse) GetStatus ¶
func (m *SubscriptionStatusResponse) GetStatus() string
func (*SubscriptionStatusResponse) ProtoMessage ¶
func (*SubscriptionStatusResponse) ProtoMessage()
func (*SubscriptionStatusResponse) Reset ¶
func (m *SubscriptionStatusResponse) Reset()
func (*SubscriptionStatusResponse) String ¶
func (m *SubscriptionStatusResponse) String() string
func (*SubscriptionStatusResponse) XXX_DiscardUnknown ¶
func (m *SubscriptionStatusResponse) XXX_DiscardUnknown()
func (*SubscriptionStatusResponse) XXX_Marshal ¶
func (m *SubscriptionStatusResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*SubscriptionStatusResponse) XXX_Merge ¶
func (m *SubscriptionStatusResponse) XXX_Merge(src proto.Message)
func (*SubscriptionStatusResponse) XXX_Size ¶
func (m *SubscriptionStatusResponse) XXX_Size() int
func (*SubscriptionStatusResponse) XXX_Unmarshal ¶
func (m *SubscriptionStatusResponse) XXX_Unmarshal(b []byte) error